@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: MailPost.pm 232 2007-02-14 13:57:07Z hikarin $
+# $Id: MailPost.pm 363 2007-03-16 15:11:10Z hikarin $
 #
 
 package Img0ch::App::MailPost;
@@ -27,9 +27,9 @@ use Net::POP3 qw();
 sub new {
     my ( $iClass, $iKernel, @args ) = @_;
     my $iApp = $iClass->SUPER::new( $iKernel, @args );
-    $iApp->{__from}   = undef;
-    $iApp->{_request} = Img0ch::App::MailPost::Request->new(
-        Img0ch::Request->new(@args));
+    $iApp->{__from} = undef;
+    $iApp->{_request}
+        = Img0ch::App::MailPost::Request->new( Img0ch::Request->new(@args) );
     return $iApp;
 }
 
@@ -40,12 +40,15 @@ sub run {
     $iApp->{_config}->get('Maintenance')
         and die 'img0ch MAINTENANCE: Please try again later.', "\n";
 
-    if ($iApp->get_mail($mail_rec)) {
-        my @args = ( 'mobile', 'shiftjis',
-            sub { ${ $_[0] } =~ s/\n//gxms; ${ $_[0] } }, \&send_error_mail );
+    if ( $iApp->get_mail($mail_rec) ) {
+        my @args = (
+            'mobile', 'shiftjis',
+            sub { ${ $_[0] } =~ s/\n//gxms; ${ $_[0] } },
+            \&send_error_mail
+        );
         $iApp->process($mail_rec) or return $iApp->redirect_error(@args);
-        $iApp->validate()     or return $iApp->redirect_error(@args);
-        $iApp->is_writeable() or return $iApp->redirect_error(@args);
+        $iApp->validate()         or return $iApp->redirect_error(@args);
+        $iApp->is_writeable()     or return $iApp->redirect_error(@args);
         $iApp->get_date();
         $iApp->post() or return $iApp->redirect_error(@args);
         $iApp->update_subback( undef, 1 );
@@ -62,7 +65,7 @@ sub redirect_success {
     my $iConfig  = $iApp->{_config};
     my $iRequest = $iApp->{_request};
 
-    if (!$iBBS) {
+    if ( !$iBBS ) {
         require Img0ch::BBS;
         my $iKernel = $iApp->kernel();
         my @path = split '/', $iRequest->path_info();
@@ -80,17 +83,18 @@ sub redirect_success {
             version => $iRequest->credit(),
         }
     );
-    $iTemplate->param({
-        Banner  => $iMeta->mobile_banner(),
-        Flag    => 0,
-        Fetch   => $fetch,
-        Referer => $iRequest->get_header('referer') || '""',
-    });
+    $iTemplate->param(
+        {   Banner  => $iMeta->mobile_banner(),
+            Flag    => 0,
+            Fetch   => $fetch,
+            Referer => $iRequest->get_header('referer') || '""',
+        }
+    );
 
     my $charset = $iConfig->get('DefaultCharset');
     $iRequest->send_http_header( 'text/html', $charset );
-    $iTemplate->flush(sub { ${ $_[0] } =~ s/\n//gxms; ${ $_[0] } });
-    1
+    $iTemplate->flush( sub { ${ $_[0] } =~ s/\n//gxms; ${ $_[0] } } );
+    1;
 }
 
 sub get_mail {
@@ -100,27 +104,29 @@ sub get_mail {
 
     my $user = $iConfig->get('POP3User');
     my $pass = $iConfig->get('POP3Pass');
-    my $pop3 = Net::POP3->new($iConfig->get('POP3Server'));
-    my $re = $iConfig->get('UseAPOP') ?
-             $pop3->apop( $user, $pass ) :
-             $pop3->login( $user, $pass );
+    my $pop3 = Net::POP3->new( $iConfig->get('POP3Server') );
+    my $re =
+          $iConfig->get('UseAPOP')
+        ? $pop3->apop( $user, $pass )
+        : $pop3->login( $user, $pass );
     if ($re) {
         my $msgnums = $pop3->list();
         my @msgs    = sort { $a <=> $b } keys %$msgnums;
         my $msgnum  = shift @msgs;
         if ($msgnum) {
             my $msg = $pop3->get($msgnum)
-                or $iKernel->throw_exception($pop3->message());
+                or $iKernel->throw_exception( $pop3->message() );
             @$mail_rec = @$msg;
-            $pop3->delete($msgnum)
-                or $iKernel->throw_exception($pop3->message());
+
+            #            $pop3->delete($msgnum)
+            #                or $iKernel->throw_exception($pop3->message());
             $pop3->quit();
             return 1;
         }
         return 0;
     }
     else {
-        $iKernel->throw_exception($pop3->message());
+        $iKernel->throw_exception( $pop3->message() );
     }
 }
 
@@ -128,8 +134,8 @@ sub send_error_mail {
     my ( $iApp, $message ) = @_;
     my $iKernel = $iApp->kernel();
     my $iConfig = $iKernel->get_config();
-    my $from  = $iConfig->get('MailRawAddress');
-    my $to    = $iApp->{__from};
+    my $from    = $iConfig->get('MailRawAddress');
+    my $to      = $iApp->{__from};
 
     require Unicode::Japanese;
     $message =~ s{<br\s?/?>}{\n}gxms;
@@ -139,58 +145,60 @@ sub send_error_mail {
     require Email::Send;
     my $sender;
     if ( my $sendmail = $iConfig->get('SendmailPath') ) {
-        $sender = Email::Send->new({ mailer => 'Sendmail' });
+        $sender = Email::Send->new( { mailer => 'Sendmail' } );
         $Email::Send::Sendmail::SENDMAIL = $sendmail;
     }
     elsif ( my $qmail = $iConfig->get('QmailPath') ) {
-        $sender = Email::Send->new({ mailer => 'Qmail' });
+        $sender = Email::Send->new( { mailer => 'Qmail' } );
         $Email::Send::Qmail::QMAIL = $qmail;
     }
     else {
         my $host = $iConfig->get('smtp.host');
         my $port = $iConfig->get_int('smtp.port');
         $port and $host = join ':', $host, $port;
-        $sender = Email::Send->new({ mailer => 'SMTP' });
-        $sender->mailer_args([
-            Host => $host,
-            ssl => $iConfig->get('smtp.ssl'),
-            tls => $iConfig->get('smtp.tls'),
-            ]);
+        $sender = Email::Send->new( { mailer => 'SMTP' } );
+        $sender->mailer_args(
+            [   Host => $host,
+                ssl  => $iConfig->get('smtp.ssl'),
+                tls  => $iConfig->get('smtp.tls'),
+            ]
+        );
     }
 
     require Img0ch::Template;
-    my $iTemplate = Img0ch::Template->new(
-        $iKernel, { file => 'mobile_error_mail' } );
-    $iTemplate->param({
-        From    => $from,
-        To      => $to,
-        Message => $message_jis,
-    });
-    my $result = $sender->send(${ $iTemplate->to_string() });
+    my $iTemplate
+        = Img0ch::Template->new( $iKernel, { file => 'mobile_error_mail' } );
+    $iTemplate->param(
+        {   From    => $from,
+            To      => $to,
+            Message => $message_jis,
+        }
+    );
+    my $result = $sender->send( ${ $iTemplate->to_string() } );
     $result or $iKernel->throw_exception($result);
     return;
 }
 
 sub process {
     my ( $iApp, $mail_rec ) = @_;
-    my $iConfig = $iApp->{_config};
-    my $iKernel = $iApp->kernel();
+    my $iConfig  = $iApp->{_config};
+    my $iKernel  = $iApp->kernel();
     my $iRequest = $iApp->request();
 
-    map { tr/\r\n//d } @$mail_rec;
-    my $mime = Email::MIME->new(join "\r\n", @$mail_rec);
-    $iApp->_get_host($iConfig, $mime) or return 0;
+    map {tr/\r\n//d} @$mail_rec;    ## no critic
+    my $mime = Email::MIME->new( join "\r\n", @$mail_rec );
+    $iApp->_get_host( $iConfig, $mime ) or return 0;
 
     require Unicode::Japanese;
     my $found = 0;
-    for my $part ($mime->parts()) {
-        if (my $fn = $part->filename()) {
+    for my $part ( $mime->parts() ) {
+        if ( my $fn = $part->filename() ) {
             my $cte = $part->header('Content-Transfer-Encoding');
-            if ($cte =~ s/\s+//gxms) {
-                $part->header_set('Content-Transfer-Encoding', $cte);
+            if ( $cte =~ s/\s+//gxms ) {
+                $part->header_set( 'Content-Transfer-Encoding', $cte );
             }
             require File::Temp;
-            my ( $fh, $temp ) = File::Temp::tempfile(UNLINK => 1);
+            my ( $fh, $temp ) = File::Temp::tempfile( UNLINK => 1 );
             binmode $fh;
             print {$fh} $part->body();
             close $fh;
@@ -198,21 +206,21 @@ sub process {
             $found++;
         }
         else {
-            $iApp->_parse_body(\$part->body()) or return 0
+            $iApp->_parse_body( \$part->body() ) or return 0;
         }
     }
-    if (!$found) {
+    if ( !$found ) {
         $iApp->set_error('INVALID_MAILPOST');
-        return 0
+        return 0;
     }
 
-    my $subject = Unicode::Japanese->new($mime->header('Subject'))->sjis();
+    my $subject = Unicode::Japanese->new( $mime->header('Subject') )->sjis();
     $subject =~ s/\A\s+//xms;
     $subject =~ s/\s+\z//xms;
     $subject =~ s/(?:\r\n)+//gxms;
     $subject =~ s/\n+//gxms;
     _nonl($subject);
-    if ($subject =~ /(.*?)<>(.*)/xms) {
+    if ( $subject =~ /(.*?)<>(.*)/xms ) {
         my ( $name, $mail ) = ( $1, $2 );
         $name =~ s/\s+\z//xms;
         $mail =~ s/\A\s+//xms;
@@ -226,12 +234,12 @@ sub process {
 
     $iApp->init() or return 0;
     my $iSetting = $iApp->setting();
-    if (!$iSetting->is_checked('BBS_ACCEPT_MAILPOST')) {
+    if ( !$iSetting->is_checked('BBS_ACCEPT_MAILPOST') ) {
         $iApp->set_error('NOT_ACCEPT_ERROR');
         return 0;
     }
 
-    1
+    1;
 }
 
 sub _parse_body {
@@ -241,9 +249,9 @@ sub _parse_body {
 
     $bbs ||= '';
     $key ||= '';
-    if ($bbs =~ /\A(?:\r\n)*([\w\-]+)\z/xms) {
+    if ( $bbs =~ /\A(?:\r\n)*([\w\-]+)\z/xms ) {
         $iRequest->set_param_internal( 'bbs', $1 );
-        if ($key =~ /\A(\d{9,10})\z/xms) {
+        if ( $key =~ /\A(\d{9,10})\z/xms ) {
             $iRequest->set_param_internal( 'key', $1 );
             $text = Unicode::Japanese->new($text)->sjis();
             _nonl($text);
@@ -256,7 +264,7 @@ sub _parse_body {
     }
 
     $iApp->set_error('INVALID_MAILPOST');
-    return 0
+    return 0;
 }
 
 sub _get_host {
@@ -272,12 +280,13 @@ sub _get_host {
     }
 
     $from =~ /<(.*?)>/xms and $from = $1;
-    if (!$iConfig->get('AcceptMailPostFromAnother')) {
-        if ( $from !~ /docomo\.ne\.jp/xms
+    if ( !$iConfig->get('AcceptMailPostFromAnother') ) {
+        if (    $from !~ /docomo\.ne\.jp/xms
             and $from !~ /ezweb\.ne\.jp/xms
             and $from !~ /jp-[dhtckrnsq]\.ne\.jp/xms
             and $from !~ /[dhtckrnsq]\.vodafone\.ne\.jp/xms
-            and $from !~ /softbank\.ne\.jp/xms ) {
+            and $from !~ /softbank\.ne\.jp/xms )
+        {
             $iApp->set_error('MAILPOST_FROM_NOT_MOBILE_ADDRESS');
             return 0;
         }
@@ -287,15 +296,15 @@ sub _get_host {
     my $ip = $mime->header('Received') || '';
     $ip =~ /.+[\[\(]([\d\.]+)[\]\)]/ixms;
     $ip = $1 || '127.0.0.1';
-    my $ip_int = pack 'C*', split('\.', $ip);
-    $iApp->{_ip} = $ip;
+    my $ip_int = pack 'C*', split( '\.', $ip );
+    $iApp->{_ip}     = $ip;
     $iApp->{_ip_int} = $ip_int;
-    $iApp->{_host} = gethostbyaddr($ip_int, 2) || $ip;
+    $iApp->{_host}   = gethostbyaddr( $ip_int, 2 ) || $ip;
 
     require Digest::MD5;
     my $seed = $iConfig->get('Seed');
     $iApp->{_serial} = Digest::MD5::md5_hex( $from, $seed );
-    1
+    1;
 }
 
 sub _nonl {
@@ -305,7 +314,7 @@ sub _nonl {
 
 package Img0ch::App::MailPost::Request;
 
-use base qw(Img0ch::RequestIF);
+use base qw(Img0ch::Request::Interface);
 
 BEGIN {
     my $pkg = __PACKAGE__;
@@ -316,8 +325,8 @@ BEGIN {
 }
 
 sub new {
-   my ( $iClass, $iRequest ) = @_;
-   bless { __orig => $iRequest, __param => {} }, $iClass;
+    my ( $iClass, $iRequest ) = @_;
+    bless { __orig => $iRequest, __param => {} }, $iClass;
 }
 
 sub signature { $_[0]->{__orig}->signature() }
@@ -348,7 +357,7 @@ sub param {
         return $value;
     }
     elsif ( wantarray and !$key ) {
-        return keys %{$iRequest->{__param}};
+        return keys %{ $iRequest->{__param} };
     }
     else {
         my $value = $iRequest->{__param}->{$key};
@@ -366,15 +375,6 @@ sub path_info { $_[0]->{__orig}->path_info() }
 
 sub is_uploadable {1}
 
-sub tempfile { $_[0]->{__tmp} }
-
-sub filename {
-    my ( $iRequest ) = @_;
-    my $filename = $iRequest->{__file};
-    $filename =~ tr/\0'"<>&//d; # '
-    return $filename;
-}
-
 sub fsize { $_[0]->{__fsize} }
 
 sub cookie { shift->{__orig}->cookie(@_) }
@@ -391,9 +391,9 @@ sub set_param_internal {
 sub upload_internal {
     my ( $iRequest, $tempfile, $filename ) = @_;
     caller() eq 'Img0ch::App::MailPost' or return;
-    $iRequest->{__file} = $filename;
+    $iRequest->{__file}  = $filename;
     $iRequest->{__fsize} = -s $tempfile || 0;
-    $iRequest->{__tmp} = $tempfile;
+    $iRequest->{__tmp}   = $tempfile;
     return;
 }
 
