@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Read.pm 317 2007-03-04 14:11:35Z hikarin $
+# $Id: Read.pm 474 2007-04-10 13:18:49Z hikarin $
 #
 
 package Img0ch::App::Read;
@@ -75,7 +75,7 @@ sub run {
         )
         )
     {
-        $iApp->_load_thread(
+        $iApp->load_thread(
             {},
             {   filter   => undef,
                 mobile   => 0,
@@ -85,7 +85,7 @@ sub run {
         );
     }
     else {
-        $iApp->_redirect_error();
+        $iApp->redirect_error();
     }
 }
 
@@ -125,7 +125,7 @@ sub init {
 
     require Img0ch::Thread;
     my $iThread = Img0ch::Thread->new( $iBBS, $key );
-    my $count   = $iThread->load();
+    my $count = $iThread->load();
     ( !$count and !$mobile ) and return 0;
 
     $iApp->{__agent}        = $iRequest->agent();
@@ -153,10 +153,10 @@ sub get_param {
         || '';
 }
 
-sub get_param_int { Img0ch::Kernel::intval(shift->get_param(@_)) }
+sub get_param_int { Img0ch::Kernel::intval( shift->get_param(@_) ) }
 
-sub _load_thread {
-    my ( $iApp, $template_vars, $option ) = @_;
+sub load_thread {
+    my ( $iApp, $template_vars, $option, $no_disk ) = @_;
     my $key      = $iApp->{_param_key};
     my $iBBS     = $iApp->{_bbs};
     my $iConfig  = $iApp->{_config};
@@ -176,19 +176,23 @@ sub _load_thread {
     my $raw               = $iApp->{_param_raw};
     my $count             = $iApp->{__thread_count};
     my $loop              = int( $count / 100 ) + 1;
-    my $max               = $iConfig->get_int('ResMAX') || 1000;
     my $omit              = $iConfig->get('OmitDefaultNoName');
     my $noname            = $iSetting->get('BBS_NONAME_NAME');
 
-    my $st = $iApp->{__read_from};
-    my $to = $iApp->{__read_to};
+    my $st        = $iApp->{__read_from};
+    my $to        = $iApp->{__read_to};
+    my $br2nl     = $option->{br2nl};
     my $parameter = {
         line    => $iApp->get_param_int('LINE'),
         nofirst => $iApp->{_param_nofirst},
         single  => $iApp->{_param_single},
         raw     => $raw,
+        br2nl   => $br2nl,
     };
 
+    my $max   = $iSetting->get_int('BBS_RES_MAX')
+         || $iConfig->get_int('ResMAX') || 1000;
+
     if (    !$iApp->{_param_nofirst}
         and !$iApp->{_param_single}
         and $read_range->[0] == 1 )
@@ -200,6 +204,7 @@ sub _load_thread {
         my $text  = $first->[4];
         ( $mobile and $omit and $name eq $noname ) and $name = '';
         $plugin->( $key, $count, 1, \$text, $parameter );
+        $br2nl and $text =~ s{<br\s*/?>}{\r}gxms;
         push @{$read_thread_stack},
             {
             index   => 1,
@@ -221,6 +226,7 @@ sub _load_thread {
         my $text = $res->[4];
         ( $mobile and $omit and $name eq $noname ) and $name = '';
         $plugin->( $key, $count, $i, \$text, $parameter );
+        $br2nl and $text =~ s{<br\s*/?>}{\r}gxms;
         push @{$read_thread_stack},
             {
             index   => $i,
@@ -249,8 +255,7 @@ sub _load_thread {
             || 1;
         $read_res = $read_res_prev = $cnum;
     }
-    my $server = $iConfig->get('CGIServer')
-        || join('/', $iConfig->get('Server'), 'test');
+    my $server = $iRequest->get_app_uri();
     my $renderer = $iConfig->get('Renderer') || 'read.cgi';
     $reader = join( '/',
         $server, $renderer, $iBBS->get_name(), $iApp->{_param_key} );
@@ -266,47 +271,168 @@ sub _load_thread {
         }
     );
 
+    $mobile or $st--;
     my $r90  = ( $count >= $max - int( $max / 10 ) ? 1 : 0 );
     my $r95  = ( $count >= $max - int( $max / 20 ) ? 1 : 0 );
     my $r100 = ( $count > $max                     ? 1 : 0 );
-    $mobile or $st--;
-    $iTemplate->param(
-        {   ( map { %{$_} } @{ $iApp->{__template_tag_read} } ),
-            '90'     => $r90,
-            '95'     => $r95,
-            '100'    => $r100,
-            'R90'    => $r90,
-            'R95'    => $r95,
-            'R100'   => $r100,
-            'Banner' => $mobile
-            ? $iMeta->main_banner()
-            : $iMeta->mobile_banner(),
-            'DatKByteSize' => int( $iThread->size() / 1024 ),
-            'KEY'          => $key,
-            'key'          => $key,
-            'LinkStack'    => $link,
-#            'NameByCookie' => ( $iRequest->cookie('NAME') || '' ),
-            'NameByCookie' => '',
-            'NextEnd' => ( $to + $read_res > $max ? $max : $to + $read_res ),
-            'NextStart'    => $to + 1,
-#            'MailByCookie' => ( $iRequest->cookie('MAIL') || '' ),
-            'MailByCookie' => '',
-            'META'         => $iMeta->meta(),
-            'PrevEnd'      => ( $st || 1 ),
-            'PrevStart' =>
-                ( $st - $read_res_prev < 1 ? 1 : $st - $read_res_prev ),
-            'ReadCGIURI' => $reader,
-            'ResCount'   => $count,
-            'Subject'    => $iThread->get_subject(),
-            'Thread'     => $read_thread_stack,
-            'ZThread'    => $read_thread_stack,
-            %{$template_vars},
+    my $template_parameters = {
+        ( map { %{$_} } @{ $iApp->{__template_tag_read} } ),
+        '90'     => $r90,
+        '95'     => $r95,
+        '100'    => $r100,
+        'R90'    => $r90,
+        'R95'    => $r95,
+        'R100'   => $r100,
+        'Banner' => $mobile
+        ? $iMeta->main_banner()
+        : $iMeta->mobile_banner(),
+        'DatKByteSize' => int( $iThread->size() / 1024 ),
+        'KEY'          => $key,
+        'key'          => $key,
+        'LinkStack'    => $link,
+
+        #       'NameByCookie' => ( $iRequest->cookie('NAME') || '' ),
+        'NameByCookie' => '',
+        'NextEnd'      => ( $to + $read_res > $max ? $max : $to + $read_res ),
+        'NextStart'    => $to + 1,
+
+        #       'MailByCookie' => ( $iRequest->cookie('MAIL') || '' ),
+        'MailByCookie' => '',
+        'META'         => $iMeta->meta(),
+        'PrevEnd'      => ( $st || 1 ),
+        'PrevStart' =>
+            ( $st - $read_res_prev < 1 ? 1 : $st - $read_res_prev ),
+        'ReadCGIURI' => $reader,
+        'ResCount'   => $count,
+        'Subject'    => $iThread->get_subject(),
+        'Thread'     => $read_thread_stack,
+        'ZThread'    => $read_thread_stack,
+        %{$template_vars},
+    };
+
+    if ($no_disk) {
+        return $template_parameters;
+    }
+    else {
+        $iTemplate->param($template_parameters);
+        $iRequest->send_http_header('text/html');
+        $iTemplate->flush( $option->{filter} );
+        return 1;
+    }
+}
+
+sub redirect_error {
+    my ( $iApp, $no_disk ) = @_;
+    my $iBBS     = $iApp->{_bbs};
+    my $iConfig  = $iApp->{_config};
+    my $iKernel  = $iApp->{_kernel};
+    my $iRequest = $iApp->{_request};
+
+    require Img0ch::Error;
+    my $key = $iApp->{_param_key} || $iRequest->key;
+    my $iError = Img0ch::Error->new( $iKernel, $key, $iRequest->ip_int() );
+    my $long = $iError->get( $iApp->{__error} || 'INVALID_POST' );
+    $iError->record();
+
+    my $bbs = $iBBS ? $iBBS->get_name() : '';
+    my $server = $iRequest->get_app_uri();
+    my $renderer = $iConfig->get('Renderer') || 'read.cgi';
+    my $reader = join( '/', $server, $renderer, $bbs, $iApp->{_param_key} );
+    my $archive_path  = '';
+    my $archive_found = 0;
+    my $banner        = '';
+    my $dat_bytes     = 0;
+    my $is_error      = 0;
+    my $meta          = '';
+    my $pool_found    = 0;
+    my $res_count     = 0;
+    my $res_stack     = [];
+    my $subject       = '';
+    if ($iBBS) {
+        $archive_path = $iBBS->path('kako');
+        require Img0ch::Archive;
+        my $iArchive = Img0ch::Archive->new($iBBS);
+        ( $subject, $res_count ) = $iArchive->get($key);
+        if ($res_count) {
+            $archive_found = 1;
+        }
+        else {
+            require Img0ch::Pool::Subject;
+            my $iPSubject = Img0ch::Pool::Subject->new($iBBS);
+            ( $subject, $res_count ) = @{ $iPSubject->get($key) };
+            if ($res_count) {
+                require Img0ch::Pool::Thread;
+                my $iPThread = Img0ch::Pool::Thread->new( $iBBS, $key );
+                $iPThread->load();
+                my @load_reses = (1);
+                $res_count != 1 and push @load_reses, $res_count;
+                for my $i (@load_reses) {
+                    my $res  = $iPThread->get($i);
+                    my $id   = $res->[3];
+                    my $date = $id ? ( join ' ', $res->[2], $id ) : $res->[2];
+                    my $text = $res->[4];
+                    push @{$res_stack},
+                        {
+                        num     => $i,
+                        resno   => $i,
+                        name    => $res->[0],
+                        mail    => $res->[1],
+                        date    => $date,
+                        text    => $text,
+                        isFirst => ( $i == 1 ? 1 : 0 ),
+                        };
+                }
+                $dat_bytes  = $iPThread->size();
+                $pool_found = 1;
+            }
+        }
+        require Img0ch::Metadata;
+        my $iMeta = Img0ch::Metadata->new($iBBS);
+        $banner = $iMeta->main_banner();
+        $meta   = $iMeta->meta();
+    }
+    else {
+        $is_error = 1;
+    }
+
+    require Img0ch::Template;
+    my $iTemplate = Img0ch::Template->new(
+        ( $iBBS || $iKernel ),
+        {   file    => 'not_found',
+            request => $iRequest,
+            setting => $iApp->{_setting},
         }
     );
-    $iRequest->send_http_header('text/html');
-    $iTemplate->flush( $option->{filter} );
+    my $template_parameters = {
+        ( map { %{$_} } @{ $iApp->{__template_tag_error} } ),
+        Archive       => $archive_path,
+        Banner        => $banner,
+        DatByteSize   => $dat_bytes,
+        DatKByteSize  => int( $dat_bytes / 1024 ),
+        IsArchived    => $archive_found,
+        IsError       => $is_error,
+        IsPooled      => $pool_found,
+        Token1        => substr( $key, 0, 4 ),
+        Token2        => substr( $key, 0, 5 ),
+        LongErrorStr  => $long,
+        META          => $meta,
+        ReadCGIURI    => $reader,
+        ResCount      => $res_count,
+        ShortErrorStr => $long,
+        Subject       => $subject,
+        Thread        => $res_stack,
+        ZThread       => $res_stack,
+    };
 
-    1;
+    if ($no_disk) {
+        return $template_parameters;
+    }
+    else {
+        $iTemplate->param();
+        $iRequest->send_http_header('text/html');
+        $iTemplate->flush();
+        return 0;
+    }
 }
 
 sub _parse_from_request {
@@ -315,23 +441,24 @@ sub _parse_from_request {
     my $temp_range = [];
 
     if ( my $path_info = $iRequest->path_info() ) {
+        $path_info =~ s{\A/?}{}gxms;
         my @path = split '/', $path_info;
         my $raw;
 
-        'test' =~ /\A(\w+)\z/xms;
-        $path[1] =~ /\A([\w\-]+)\z/xms;
+        'test'   =~ /\A(\w+)\z/xms;
+        $path[0] =~ /\A([\w\-]+)\z/xms;
         my $bbs = $iApp->{_param_bbs} = $1;
         '0000000000' =~ /\A(\d+)\z/xms;
-        $path[2] =~ /\A(\d{9,10})\z/xms;
+        $path[1]     =~ /\A(\d{9,10})\z/xms;
         my $key = $iApp->{_param_key} = $1;
 
         my $extent_param_parser = sub {
             my ( $iApp, $parameter ) = @_;
             my $extend_param = $parameter;
-            $extend_param =~ s/\A.*?[\!\?]//xms;
+            $extend_param =~ s/\A[^\!\?]*//xms;
             $iApp->{_query_with_extend_params} = $extend_param;
             my $extend_params = {};
-            my $found = 0;
+            my $found         = 0;
             for my $chunk ( split /[&;]/xms, $extend_param ) {
                 my ( $name, $value ) = split /[\+=]/, $chunk;
                 $extend_params->{$name}
@@ -345,20 +472,20 @@ sub _parse_from_request {
         if ( $key ne '0000000000' and @path >= 4 ) {
             if ($mobile) {
                 my $query = '';
-                $raw = $path[4] || '';
-                $raw ? ( $query = $path[3] ) : ( $raw = $path[3] || '' );
+                $raw = $path[3] || '';
+                $raw ? ( $query = $path[2] ) : ( $raw = $path[2] || '' );
                 $extent_param_parser->( $iApp, $query );
             }
             else {
-                $raw = $path[3] || '';
+                $raw = $path[2] || '';
             }
         }
         elsif ( $bbs ne 'test' and @path >= 3 ) {
-            $raw = $path[3] || ( $mobile ? $path[2] : '' );
-            $extent_param_parser->( $iApp, $path[2] );
+            $raw = $path[2] || ( $mobile ? $path[1] : '' );
+            $extent_param_parser->( $iApp, $path[1] );
         }
         else {
-            $raw = $path[3] || ( $mobile ? $path[2] : '' );
+            $raw = $path[2] || ( $mobile ? $path[1] : '' );
         }
         $iApp->{_param_raw} = $raw;
         $raw =~ s/[acCi]\z//xms;
@@ -408,8 +535,9 @@ sub _parse_from_request {
                 $param_recent  ||= $read_recent;
                 $param_nofirst ||= $read_nofirst;
             }
+
             #warn scalar keys %$temp_range_hash, "\n";
-            $iApp->{_param_ls} = $param_recent;
+            $iApp->{_param_ls}      = $param_recent;
             $iApp->{_param_nofirst} = $param_nofirst;
         }
         else {
@@ -435,19 +563,19 @@ sub _parse_from_request {
     else {
         $iApp->get_param('bbs') =~ /([\w\-]+)/xms;
         $iApp->{_param_bbs} = $1;
-        '0000000000'        =~ /\A(\d+)\z/xms;
+        '0000000000'            =~ /\A(\d+)\z/xms;
         $iApp->get_param('key') =~ /(\d{9,10})/;
         $iApp->{_param_key} = $1;
         $iApp->{_param_raw} = '';
-        my $read_from = Img0ch::Kernel::intval($iApp->get_param('st')) || 1;
-        my $read_to   = Img0ch::Kernel::intval($iApp->get_param('to'))
+        my $read_from = Img0ch::Kernel::intval( $iApp->get_param('st') ) || 1;
+        my $read_to = Img0ch::Kernel::intval( $iApp->get_param('to') )
             || $max_read;
         my $read_recent = $iApp->{_param_ls} = $iApp->get_param('last')
             || $iApp->get_param('ls');
         my $single = $iApp->{_param_single}
             = ( $read_from == $read_to and !$read_recent ) ? 1 : 0;
         $iApp->{_param_nofirst} = ( $single
-            || ( $iApp->get_param('nofirst') eq 'true' ? 1 : 0 ) );
+                || ( $iApp->get_param('nofirst') eq 'true' ? 1 : 0 ) );
         $read_from > $max_read and $read_from = $max_read;
         $read_to > $max_read   and $read_to   = $max_read;
         push @{$temp_range}, sort { $a <=> $b } ( $read_from .. $read_to );
@@ -467,14 +595,18 @@ sub _normalize {
     my $temp_read_from = $temp_range->[0] || 1;
     my $temp_read_to   = $temp_range->[-1] || $temp_read_from;
     my ( $real_read_from, $real_read_to, $read_by_const ) = (
-        0, 0, ( $iApp->get_param_int('RES') ||
-        $iApp->{_setting}->get_int('BBS_MB_CONTENTS_NUMBER') || 1 )
+        0, 0,
+        (          $iApp->get_param_int('RES')
+                || $iApp->{_setting}->get_int('BBS_MB_CONTENTS_NUMBER')
+                || 1
+        )
     );
 
     if ($is_mobile) {
         $read_by_const--;
         if ( $raw =~ /\A(n)?[acCi]*\z/xms ) {
             $last = 1;
+
             # $temp_read_to = 1001 ( ResMAX )
             #     =>
             # $temp_read_to = 10 ( $read_by_const )
@@ -483,10 +615,10 @@ sub _normalize {
         }
         elsif ( $raw =~ /l(\d+)(n)?/xms ) {
             my $read_range = $1;
-            $last = 1;
-            $nofirst = $iApp->{_param_nofirst} = $2 ? 1 : 0;
+            $last          = 1;
+            $nofirst       = $iApp->{_param_nofirst} = $2 ? 1 : 0;
             $read_by_const = $read_range;
-            $temp_read_to = $read_range - 1;
+            $temp_read_to  = $read_range - 1;
         }
         else {
             $nofirst = $iApp->{_param_nofirst} = 1;
@@ -502,7 +634,7 @@ sub _normalize {
         @{$temp_range} = $real_read_from .. $real_read_to;
         $iApp->{__read_from} = $real_read_from;
         $iApp->{__read_to}   = $real_read_to;
-        if (!$nofirst) {
+        if ( !$nofirst ) {
             $real_read_from = 1;
             $temp_range->[0] != 1 and unshift @{$temp_range}, 1;
         }
@@ -525,8 +657,9 @@ sub _normalize {
         $iApp->{__read_from} = $temp_read_from;
         $iApp->{__read_to}   = $real_read_to;
     }
-#    ( $is_mobile and $real_read_to - $real_read_from > $read_by_const )
-#        and $real_read_from = $real_read_to - $read_by_const;
+
+    #    ( $is_mobile and $real_read_to - $real_read_from > $read_by_const )
+    #        and $real_read_from = $real_read_to - $read_by_const;
 
     my $real_range = [];
     foreach my $i ( @{$temp_range} ) {
@@ -540,115 +673,5 @@ sub _normalize {
     1;
 }
 
-sub _redirect_error {
-    my ($iApp)   = @_;
-    my $iBBS     = $iApp->{_bbs};
-    my $iConfig  = $iApp->{_config};
-    my $iKernel  = $iApp->{_kernel};
-    my $iRequest = $iApp->{_request};
-
-    require Img0ch::Error;
-    my $key = $iApp->{_param_key} || $iRequest->key;
-    my $iError = Img0ch::Error->new( $iKernel, $key, $iRequest->ip_int() );
-    my $long = $iError->get( $iApp->{__error} || 'INVALID_POST' );
-    $iError->record();
-
-    my $bbs = $iBBS ? $iBBS->get_name() : '';
-    my $server = $iConfig->get('CGIServer')
-        || join('/', $iConfig->get('Server'), 'test');
-    my $renderer = $iConfig->get('Renderer') || 'read.cgi';
-    my $reader = join( '/', $server, $renderer, $bbs, $iApp->{_param_key} );
-    my $archive_path  = '';
-    my $archive_found = 0;
-    my $banner        = '';
-    my $dat_bytes     = 0;
-    my $is_error      = 0;
-    my $meta          = '';
-    my $pool_found    = 0;
-    my $res_count     = 0;
-    my $res_stack     = [];
-    my $subject       = '';
-    if ($iBBS) {
-        $archive_path = $iBBS->path('kako');
-        require Img0ch::Archive;
-        my $iArchive = Img0ch::Archive->new($iBBS);
-        ( $subject, $res_count ) = $iArchive->get($key);
-        if ($res_count) {
-            $archive_found = 1;
-        }
-        else {
-            require Img0ch::Pool::Subject;
-            my $iPSubject = Img0ch::Pool::Subject->new($iBBS);
-            ( $subject, $res_count ) = @{ $iPSubject->get($key) };
-            if ($res_count) {
-                require Img0ch::Pool::Thread;
-                my $iPThread = Img0ch::Pool::Thread->new( $iBBS, $key );
-                $iPThread->load();
-                my @load_reses = ( 1 );
-                $res_count != 1 and push @load_reses, $res_count;
-                for my $i (@load_reses) {
-                    my $res  = $iPThread->get($i);
-                    my $id   = $res->[3];
-                    my $date = $id ? ( join ' ', $res->[2], $id ) : $res->[2];
-                    my $text = $res->[4];
-                    push @{$res_stack},
-                        {
-                        num     => $i,
-                        resno   => $i,
-                        name    => $res->[0],
-                        mail    => $res->[1],
-                        date    => $date,
-                        text    => $text,
-                        isFirst => ( $i == 1 ? 1 : 0 ),
-                        };
-                }
-                $dat_bytes  = $iPThread->size();
-                $pool_found = 1;
-            }
-        }
-        require Img0ch::Metadata;
-        my $iMeta = Img0ch::Metadata->new($iBBS);
-        $banner = $iMeta->main_banner();
-        $meta   = $iMeta->meta();
-    }
-    else {
-        $is_error = 1;
-    }
-
-    require Img0ch::Template;
-    my $iTemplate = Img0ch::Template->new(
-        ( $iBBS || $iKernel ),
-        {   file    => 'not_found',
-            request => $iRequest,
-            setting => $iApp->{_setting},
-        }
-    );
-    $iTemplate->param(
-        {   ( map { %{$_} } @{ $iApp->{__template_tag_error} } ),
-            Archive => $archive_path,
-            Banner => $banner,
-            DatByteSize => $dat_bytes,
-            DatKByteSize => int($dat_bytes / 1024),
-            IsArchived => $archive_found,
-            IsError => $is_error,
-            IsPooled => $pool_found,
-            Token1 => substr( $key, 0, 4 ),
-            Token2 => substr( $key, 0, 5 ),
-            LongErrorStr => $long,
-            META         => $meta,
-            ReadCGIURI => $reader,
-            ResCount => $res_count,
-            ShortErrorStr => $long,
-            Subject => $subject,
-            Thread => $res_stack,
-            ZThread => $res_stack,
-        }
-    );
-    $iApp->{_request}->send_http_header('text/html');
-    $iTemplate->flush();
-
-    0;
-}
-
 1;
 __END__
