@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: bbs.pm 233 2007-02-14 13:57:22Z hikarin $
+# $Id: bbs.pm 398 2007-03-21 13:57:43Z hikarin $
 #
 
 package Zeromin::App::bbs;
@@ -96,16 +96,23 @@ sub load {
         'thread_end' => sub { $meta->( 'thread_end', @_ ) },
     };
 
+    my $iRequest = $zApp->request();
     if ( my $iBBS = $zApp->bbs() ) {
         ( $bbs_range == 0 or $iBBS->get_id() == $bbs_range )
             or return { code => 1 };
-        my $type = $zApp->request()->param('type');
+        my $type = $iRequest->param('type');
         exists $subs->{$type}
             and return $subs->{$type}->( $iBBS, $zUser, $unijp, $encoding );
     }
 
     my $zBBS = Zeromin::BBS->new( $iKernel, { bbs => '' } );
-    return $bbs_range ? $zBBS->get( $bbs_range, $unijp ) : $zBBS->all($unijp);
+    my $ret
+        = $bbs_range ? $zBBS->get( $bbs_range, $unijp ) : $zBBS->all($unijp);
+    if ( my $offset = $iRequest->param_int('offset') ) {
+        my $item = $iRequest->param_int('item') || 10;
+        $ret = $zApp->paging_from_array( $ret, $offset, $item );
+    }
+    return $ret;
 }
 
 sub save {
@@ -153,8 +160,9 @@ sub save {
         require Zeromin::Metadata;
         my $iRequest = $zApp->request();
         my $zMeta    = Zeromin::Metadata->new($iBBS);
-        my $value    = $iRequest->param( 'content', 1 ) || '';
-        $zMeta->$method( \$unijp->set( $value, 'utf8' )->$encoding );
+        my $value    = $iRequest->param_multibyte( 'content', $encoding, 1 )
+            || '';
+        $zMeta->$method( \$value );
         $zApp->logger( 1, 'MODIFIED META DATA: %s', [$method] );
         { code => 0 };
     };
@@ -163,23 +171,23 @@ sub save {
             $setting->( [ 'BBS_MODE', 'BBS_SUBTITLE', 'BBS_TITLE' ], @_ );
         },
         'setting' => sub { $setting->( [], @_ ) },
-        'head'       => sub { $meta->( 'head',       'can_edit_head', @_ ) },
-        'meta'       => sub { $meta->( 'meta',       'can_edit_meta', @_ ) },
-        'foot'       => sub { $meta->( 'foot',       'can_edit_foot', @_ ) },
+        'head'       => sub { $meta->( 'head', 'can_edit_head', @_ ) },
+        'meta'       => sub { $meta->( 'meta', 'can_edit_meta', @_ ) },
+        'foot'       => sub { $meta->( 'foot', 'can_edit_foot', @_ ) },
         'thread_end' => sub {
-            my ( $zApp, $iBBS, $zSetting, $zUser, $unijp ) = @_;
+            my ( $zApp, $iBBS, $zSetting, $zUser, $unijp, $encoding ) = @_;
             $zUser->can_edit_head() or return { code => 1 };
             my $iRequest = $zApp->request();
-            my $date = $iRequest->param('date');
+            my $date     = $iRequest->param('date');
             $date =~ /\AOver\s+\d+\s+Thread\z/xms or return { code => 2 };
-            my $from = $iRequest->param_multibyte( 'FROM', 'sjis' );
-            my $mail = $iRequest->param_multibyte( 'mail', 'sjis' );
-            my $text = $iRequest->param_multibyte( 'MESSAGE', 'sjis' );
+            my $from = $iRequest->param_multibyte( 'FROM',    $encoding );
+            my $mail = $iRequest->param_multibyte( 'mail',    $encoding );
+            my $text = $iRequest->param_multibyte( 'MESSAGE', $encoding );
             $text =~ s/\r\n/\n/gxms;
             $text =~ s/\n/<br>/gxms;
             my $content = join '<>', $from, $mail, $date, $text, '';
             require Zeromin::Metadata;
-            Zeromin::Metadata->new($iBBS)->thread_end(\$content);
+            Zeromin::Metadata->new($iBBS)->thread_end( \$content );
             $zApp->logger( 1, 'MODIFIED META DATA: %s', ['thread_end'] );
             return { code => 0 };
         },
@@ -220,8 +228,9 @@ sub create {
     my $zBBS = Zeromin::BBS->new( $iKernel, { bbs => $bbs } );
     $zBBS->create(
         {   category   => $param->{bbs_category},
+            request    => $iRequest,
             sub_title  => $unijp->set( $subname, 'utf8' )->$encoding,
-            title      => $unijp->set( $name,    'utf8' )->$encoding,
+            title      => $unijp->set( $name, 'utf8' )->$encoding,
             uploadable => $param->{bbs_uploadable},
         }
     ) or return { code => 7 };
@@ -344,11 +353,12 @@ sub _task {
     $zUser->$priv_meth or return { code => 1 };
     my $status = {};
 
-    my @param = $zApp->request()->param('bbs');
+    my $iRequest = $zApp->request();
+    my @param = $iRequest->param('bbs');
     for my $id (@param) {
         $id = Img0ch::Kernel::intval($id) || next;
         my $zBBS = Zeromin::BBS->new( $zApp->kernel(), { id => $id } );
-        if ( $zBBS->$task_meth($id) ) {
+        if ( $zBBS->$task_meth( $id, $iRequest ) ) {
             $zApp->logger( 1, ( $success . ': %s' ), [$id] );
             $status->{$id} = 1;
         }
