@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Setting.pm 272 2007-02-20 15:27:30Z hikarin $
+# $Id: Setting.pm 363 2007-03-16 15:11:10Z hikarin $
 #
 
 package Zeromin::Setting;
@@ -49,8 +49,9 @@ my $stringify = {
 
 sub new {
     my ( $zClass, $iObject ) = @_;
-    my $iBBS     = ( ref $iObject || '' ) eq 'Zeromin::BBS'
-                 ? $iObject->parent() : $iObject;
+    my $iBBS = ( ref $iObject || '' ) eq 'Zeromin::BBS'
+        ? $iObject->parent()
+        : $iObject;
     my $iKernel  = $iBBS->get_kernel();
     my $zSetting = $zClass->SUPER::new($iBBS);
     $zSetting->{__bbs}      = $iBBS;
@@ -93,7 +94,7 @@ sub gets {
 
 sub get_normalized {
     my ( $zSetting, $key, $unijp ) = @_;
-    my $info = $zSetting->{__info};
+    my $info  = $zSetting->{__info};
     my $hash  = $info->{$key} or return '';
     my $value = $zSetting->get($key);
 
@@ -229,10 +230,10 @@ sub save {
             or $iKernel->throw_io_exception($path);
         print {*FH} $dir, '@', crypt( $dir, $dir ), "\n";
         for my $key ( @{$keyset} ) {
-            my $value = $cache->{$key};
+            my $value    = $cache->{$key};
             my $key_info = $info->{$key};
             $key_info->{opened} or next;
-            if (exists $key_info->{except}) {
+            if ( exists $key_info->{except} ) {
                 $key_info->{except} eq $value and next;
             }
             print {*FH} $key, '=', $value, "\n"
@@ -249,7 +250,7 @@ sub save {
 
 sub remove {
     my ( $zSetting, $no_disk ) = @_;
-    my $path   = $zSetting->path();
+    my $path = $zSetting->path();
 
     %{ $zSetting->{__setting} } = ();
     $zSetting->flush();
