@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: User.pm 60 2006-12-31 00:29:40Z hikarin $
+# $Id: User.pm 389 2007-03-20 14:00:43Z hikarin $
 #
 
 package Zeromin::User;
@@ -23,7 +23,7 @@ use strict;
 use Digest::MD5 qw();
 
 BEGIN {
-    my $pkg = __PACKAGE__;
+    my $pkg        = __PACKAGE__;
     my @privileges = qw(
         can_login
         can_enter_user_section
@@ -47,6 +47,7 @@ BEGIN {
         can_create_bbs
         can_update_bbs
         can_remove_bbs
+        can_enter_setting_section
         can_change_main_setting
         can_change_color_setting
         can_change_restriction_setting
@@ -94,8 +95,9 @@ BEGIN {
         can_enter_plugin_section
         can_regist_plugin
         can_config_plugin
-        );
-    for my $privilege ( @privileges ) {
+    );
+
+    for my $privilege (@privileges) {
         my $attr = '__' . $privilege;
         no strict 'refs';
         *{"${pkg}::${privilege}"} = sub { $_[0]->{$attr} || 0 }
@@ -112,15 +114,15 @@ sub new {
 
     if ( $class eq 'Img0ch::BBS' ) {
         $iKernel = $iObject->get_kernel();
-        $zUser->{__bbs} = $iObject->id();
+        $zUser->{__bbs} = $iObject->get_id();
     }
-    elsif ( $class eq 'Img0ch::Maple' ) {
+    elsif ( $class eq 'Img0ch::Kernel' or $class eq 'Img0ch::Maple' ) {
         $iKernel = $iObject;
         $zUser->{__bbs} = 0;
     }
     else {
         Img0ch::Kernel->throw_exception(
-            'Img0ch::BBS or Img0ch::Maple not given');
+            'Img0ch::BBS or Img0ch::Maple(Img0ch::Kernel) not given');
     }
 
     my $repos_path = $iKernel->get_repos_path('user');
@@ -146,30 +148,32 @@ sub save {
     my ($zUser) = @_;
     my $iRepos = $zUser->{__repos};
 
+    my $ucount = $zUser->get_user_count();
     my $up = $zUser->{__user_pool};
     for my $id ( keys %{$up} ) {
         my $value = $up->{$id};
-        my $name  = $value->{name} || '';
+        my $name = $value->{name} || '';
         $iRepos->set( "I:U:I.${id}.name", $name );
         $iRepos->set( "I:U:I.${id}.mail", $value->{mail} || '' );
         $iRepos->set( "I:U:I.${id}.pass", $value->{pass} || '' );
-        $iRepos->set( "I:U:I.${id}.gid",  $value->{gid}  || 0 );
+        $iRepos->set( "I:U:I.${id}.gid",  $value->{gid} || 0 );
         $iRepos->set( "I:U:I.${name}.id", $id );
+        $ucount++;
     }
 
     my $gp = $zUser->{__group_pool};
     for my $id ( keys %{$gp} ) {
-        my $value = $gp->{$id};
-        my $name  = $value->{name} || '';
+        my $value     = $gp->{$id};
+        my $name      = $value->{name} || '';
         my $privilege = $value->{privilege};
         $iRepos->set( "I:U:G.${id}.name",        $name );
-        $iRepos->set( "I:U:G.${id}.role",        $value->{role}       || 1 );
-        $iRepos->set( "I:U:G.${id}.role.user",   $privilege->{user}   || 0 );
-        $iRepos->set( "I:U:G.${id}.role.cap",    $privilege->{cap}    || 0 );
-        $iRepos->set( "I:U:G.${id}.role.bbs",    $privilege->{bbs}    || 0 );
+        $iRepos->set( "I:U:G.${id}.role",        $value->{role} || 1 );
+        $iRepos->set( "I:U:G.${id}.role.user",   $privilege->{user} || 0 );
+        $iRepos->set( "I:U:G.${id}.role.cap",    $privilege->{cap} || 0 );
+        $iRepos->set( "I:U:G.${id}.role.bbs",    $privilege->{bbs} || 0 );
         $iRepos->set( "I:U:G.${id}.role.thread", $privilege->{thread} || 0 );
-        $iRepos->set( "I:U:G.${id}.role.res",    $privilege->{res}    || 0 );
-        $iRepos->set( "I:U:G.${id}.role.pool",   $privilege->{pool}   || 0 );
+        $iRepos->set( "I:U:G.${id}.role.res",    $privilege->{res} || 0 );
+        $iRepos->set( "I:U:G.${id}.role.pool",   $privilege->{pool} || 0 );
         $iRepos->set( "I:U:G.${id}.role.archive",
             $privilege->{archive} || 0 );
         $iRepos->set( "I:U:G.${id}.role.subject",
@@ -183,12 +187,14 @@ sub save {
             $privilege->{category} || 0 );
         $iRepos->set( "I:U:G.${id}.role.view",   $privilege->{view}   || 0 );
         $iRepos->set( "I:U:G.${id}.role.plugin", $privilege->{plugin} || 0 );
-        $iRepos->set( "I:U:G.${name}.id", $id );
+        $iRepos->set( "I:U:G.${name}.id",        $id );
+
         for my $bbs ( @{ $value->{bbs} } ) {
             $iRepos->set( "I:U:G:S.${id}.${bbs}", 1 );
         }
     }
 
+    $iRepos->set( 'I:U:I._', $ucount );
     $iRepos->set( 'I:U:G._', $zUser->{__group_id} );
     $iRepos->save();
     1;
@@ -205,10 +211,11 @@ sub is_valid {
     my $uid    = Digest::MD5::md5_base64($name);
     $iRepos->get("I:U:I.${uid}.pass") eq $pass or return 0;
 
-    my $bbs   = $zUser->{__bbs};
-    my $gid   = $iRepos->get_int("I:U:I.${uid}.gid") or return 0;
-    my $scope = $iRepos->get("I:U:G:S.${gid}.${bbs}")
-        || $iRepos->get("I:U:G:S.${gid}.0");
+    my $bbs    = $zUser->{__bbs};
+    my $gid    = $iRepos->get_int("I:U:I.${uid}.gid") or return 0;
+    my $global = $iRepos->get("I:U:G:S.${gid}.0");
+    my $scope  = $iRepos->get("I:U:G:S.${gid}.${bbs}") || $global;
+    $global and $zUser->{__bbs} = 0;
 
     if ( !$scope ) {
         $zUser->{__id}        = $uid;
@@ -249,6 +256,7 @@ sub is_valid {
         $zUser->{__can_remove_bbs}     = $r_bbs & 4 ? 1 : 0;
         $zUser->{__can_update_bbslist} = $r_bbs & 8 ? 1 : 0;
         my $r_pref = $iRepos->get_int("I:U:G.${gid}.role.setting");
+        $zUser->{__can_enter_setting_section}      = $r_pref      ? 1 : 0;
         $zUser->{__can_change_main_setting}        = $r_pref & 1  ? 1 : 0;
         $zUser->{__can_change_color_setting}       = $r_pref & 2  ? 1 : 0;
         $zUser->{__can_change_restriction_setting} = $r_pref & 4  ? 1 : 0;
@@ -316,6 +324,28 @@ sub is_valid {
     0;
 }
 
+sub get_bbs_range {
+    my ( $zUser, $user_id ) = @_;
+    $user_id ||= $zUser->{__id};
+
+    my $iRepos = $zUser->{__repos};
+    my $gid = $zUser->get_user_gid($user_id);
+    $iRepos->get("I:U:G:S.${gid}.0") and return [];
+
+    my $result = [];
+    $iRepos->iterate(
+        sub {
+            my ( $key, $value, $gid, $result ) = @_;
+            if ( $key =~ /\AI:U:G:S.$gid.(\d+)\z/xms ) {
+                push @$result, $1;
+            }
+            return 0;
+        },
+        $gid, $result,
+    );
+    return $result;
+}
+
 sub get_current_user {
     {   id   => $_[0]->{__id},
         name => $_[0]->{__name},
@@ -325,6 +355,37 @@ sub get_current_user {
     };
 }
 
+sub get_user_count {
+    my ($zUser) = @_;
+    my $iRepos = $zUser->{__repos};
+    my $count  = $iRepos->get_int('I:U:I._');
+
+    if (!$count) {
+        my $result = {};
+        $iRepos->iterate(
+            sub {
+                my ( $key, $value, $result ) = @_;
+                if ( $key =~ /\AI:U:I.([^\.]+)\.\w+\z/xms ) {
+                    $result->{$1} = 1;
+                }
+                return 0;
+            },
+            $result,
+        );
+        $count = scalar keys %$result;
+    }
+    return $count;
+}
+
+sub have_privilege {
+    my ( $zUser, $bbs_id ) = @_;
+    my $iRepos = $zUser->{__repos};
+    my $gid    = $zUser->{__gid};
+    $bbs_id    = Img0ch::Kernel::intval($bbs_id);
+    $iRepos->get("I:U:G:S.${gid}.${bbs_id}")
+        || $iRepos->get("I:U:G:S.${gid}.0");
+}
+
 sub add {
     my ( $zUser, $user ) = @_;
     $zUser->get_group_name( $user->{gid} ) or return 0;
@@ -344,12 +405,12 @@ sub edit {
 
     if ( !exists $up->{$id} ) {
         my $iRepos = $zUser->{__repos};
-        my $gid    = $zUser->get("I:U:I.${id}.gid");
+        my $gid    = $iRepos->get("I:U:I.${id}.gid");
         if ($gid) {
             $up->{$id} = {
-                name => $zUser->get("I:U:I.${id}.name"),
-                mail => $zUser->get("I:U:I.${id}.mail"),
-                pass => $zUser->get("I:U:I.${id}.pass"),
+                name => $iRepos->get("I:U:I.${id}.name"),
+                mail => $iRepos->get("I:U:I.${id}.mail"),
+                pass => $iRepos->get("I:U:I.${id}.pass"),
                 gid  => $gid,
             };
         }
@@ -377,6 +438,7 @@ sub remove {
     $iRepos->remove("I:U:I.${uid}.pass");
     $iRepos->remove("I:U:I.${uid}.gid");
     $iRepos->remove("I:U:I.${name}.id");
+    $iRepos->set( 'I:U:I._', $zUser->get_user_count() - 1 );
     $zUser->_plugin( 'zeromin.remove.user', [$uid] );
     1;
 }
@@ -437,6 +499,15 @@ sub get_users {
     $ret;
 }
 
+sub get_users_with_page {
+    my ( $zUser, $item_per_page, $offset ) = @_;
+
+    require Data::Page;
+    my $entries = $zUser->get_users();
+    my $page = Data::Page->new( scalar @$entries, $item_per_page, $offset );
+    return ( [ $page->splice($entries) ], $page );
+}
+
 sub get_user_id {
     my ( $zUser, $name ) = @_;
     while ( my ( $uid, $value ) = each %{ $zUser->{__user_pool} } ) {
@@ -444,7 +515,7 @@ sub get_user_id {
     }
 
     my $iRepos = $zUser->{__repos};
-    my $id = $iRepos->get("I:U:I.${name}.id");
+    my $id     = $iRepos->get("I:U:I.${name}.id");
     $id and return $id;
 
     $iRepos->iterate(
@@ -468,7 +539,7 @@ sub get_user_mail { shift->_get( 'user', 'mail', @_ ) }
 sub get_user_pass { shift->_get( 'user', 'pass', @_ ) }
 
 sub get_user_gid {
-    Img0ch::Kernel::intval( shift->_get( 'user', 'gid', @_ ) )
+    Img0ch::Kernel::intval( shift->_get( 'user', 'gid', @_ ) );
 }
 
 sub get_user_belongs { shift->_get( 'user', 'bbs', @_ ) }
@@ -479,13 +550,13 @@ sub add_group {
     my $bbs     = $group->{bbs};
     my $seen    = {};
 
-    defined $bbs or $bbs = [ $zUser->{__bbs} ];
+    defined $bbs or return 0;
     ( ref $bbs || '' ) eq 'ARRAY' or $bbs = [$bbs];
     for my $scope (@$bbs) {
         $scope = Img0ch::Kernel::intval($scope);
         if ($scope) {
             my $iBBS = Img0ch::BBS->new( $iKernel, { id => $scope } );
-            my $id = $iBBS->id() || return 0;
+            my $id = $iBBS->get_id() || return 0;
             $seen->{$id} = 1;
         }
         else {
@@ -496,7 +567,7 @@ sub add_group {
     @{ $group->{bbs} } or @{ $group->{bbs} } = (0);
 
     my $gid = ++$zUser->{__group_id};
-    $zUser->_plugin('zeromin.create.ugroup', [ $gid, $group ] );
+    $zUser->_plugin( 'zeromin.create.ugroup', [ $gid, $group ] );
     $zUser->{__group_pool}->{$gid} = $group;
     return $gid;
 }
@@ -515,7 +586,7 @@ sub edit_group {
             $scope = Img0ch::Kernel::intval($scope);
             if ($scope) {
                 my $iBBS = Img0ch::BBS->new( $iKernel, { id => $scope } );
-                my $id = $iBBS->id() || return 0;
+                my $id = $iBBS->get_id() || return 0;
                 $seen->{$id} = 1;
             }
             else {
@@ -584,17 +655,17 @@ sub remove_group {
 
     exists $gp->{$gid} and delete $gp->{$gid};
     my $name = $iRepos->remove("I:U:G.${gid}.name");
-    $iRepos->remove("I:U:G.${gid}.privilege");
     $iRepos->remove("I:U:G.${name}.id");
     $iRepos->iterate(
         sub {
             my ( $key, $value, $gid ) = @_;
+            $key =~ /\AI:U:G\.$gid/xms   and return -1;
             $key =~ /\AI:U:G:S\.$gid/xms and return -1;
             return 0;
         },
         $gid
     );
-    $zUser->_plugin( 'zeromin.remove.ugroup', [ $gid ] );
+    $zUser->_plugin( 'zeromin.remove.ugroup', [$gid] );
     return 1;
 }
 
@@ -733,6 +804,15 @@ sub get_groups {
     $ret;
 }
 
+sub get_groups_with_page {
+    my ( $zUser, $item_per_page, $offset ) = @_;
+
+    require Data::Page;
+    my $entries = $zUser->get_groups();
+    my $page = Data::Page->new( scalar @$entries, $item_per_page, $offset );
+    return ( [ $page->splice($entries) ], $page );
+}
+
 sub get_group_id {
     my ( $zUser, $name ) = @_;
     while ( my ( $gid, $value ) = each %{ $zUser->{__group_pool} } ) {
@@ -740,7 +820,7 @@ sub get_group_id {
     }
 
     my $iRepos = $zUser->{__repos};
-    my $id = $iRepos->get("I:U:G.${name}.id");
+    my $id     = $iRepos->get("I:U:G.${name}.id");
     $id and return $id;
 
     $iRepos->iterate(
@@ -765,7 +845,8 @@ sub get_group_belongs {
 
 sub remove_from_bbs {
     my ( $zUser, $bbs_id ) = @_;
-    $bbs_id ||= $zUser->{__bbs};
+    $bbs_id or return 0;
+
     my $iRepos = $zUser->{__repos};
     $iRepos->iterate(
         sub {
